#! /usr/bin/env python
# -*- coding:utf-8 -*-
# Author: ljw

phones = {"1107": "OPPO 1107",
          "15 Plus": "魅族 15 Plus",
          "15": "魅族 15",
          "1501-A02": "360奇酷 F4",
          "1503-A01": "360奇酷 N4",
          "1505-A01": "360奇酷 N4S",
          "1505-A02": "360 N4S",
          "1515-A01": "360奇酷 Q5",
          "16 X": "魅族 16X",
          "1603-A03": "360奇酷 N4A",
          "1605-A01": "360奇酷 N5",
          "1607-A01": "360奇酷 N5S",
          "16th Plus": "魅族 16th Plus",
          "16th": "魅族 16th",
          "1707-A01": "360 N6",
          "1801-A01": "360 N6 Pro",
          "1803-A01": "360 N7 Lite",
          "1807-A01": "360 N7",
          "1809-A01": "360 N7 Pro",
          "2013022": "红米 手机",
          "2014011": "红米 1S",
          "2014501": "红米 1S ",
          "2014813": "红米 2A",
          "401SO": "索尼 Xperia Z3 ",
          "506SH": "夏普 AQUOS Xx3",
          "831C": "HTC One M8",
          "8676-A01": "酷派 大神 Note 3",
          "8681-M02": "360奇酷 青春版",
          "8692-A00": "360奇酷 旗舰版",
          "A0001": "一加 1",
          "A11": "OPPO A11",
          "A31": "OPPO A31",
          "ALE-UL00": "华为 P8 青春版",
          "ALP-AL00": "华为 Mate 10",
          "ANE-AL00": "华为 nova 3e",
          "ARE-AL00": "华为 荣耀 8X Max",
          "ASUS_T00J": "华硕 ZenFone 5",
          "ASUS_X550": "华硕 飞马2 Plus",
          "ASUS_Z00UD": "Zenfone Selfie",
          "ASUS_Z012DE": "华硕 ZenFone 3",
          "ASUS_Z016DA": "华硕 ZenFone 3",
          "ASUS_Z01QD": "华硕 ROG",
          "ATH-AL00": "华为 荣耀 7i",
          "ATH-UL00": "华为 荣耀 7i",
          "ATU-AL10": "华为 畅享 8e",
          "AUM-AL20": "华为 荣耀畅玩 7A",
          "BAC-TL00": "华为 nova 2 Plus",
          "BKL-AL00": "华为 荣耀 V10",
          "BKL-AL20": "华为 荣耀 V10",
          "BLA-AL00": "华为 Mate 10 Pro",
          "BLN-AL10": "华为 荣耀畅玩 6X",
          "BLN-AL30": "华为 荣耀畅玩 6X",
          "BLN-AL40": "华为 荣耀畅玩 6X",
          "BLN-TL10": "华为 荣耀畅玩 6X",
          "BND-AL10": "华为 荣耀畅玩 7X",
          "BTV-W09": "华为 MediaPad M3",
          "C105": "酷派 cool S1",
          "C106": "酷派 cool1",
          "C107-9": "酷派 cool 1C",
          "C2105": "索尼 C2105",
          "C8817D": "华为 荣耀 畅玩4",
          "CAM-AL00": "华为 荣耀畅玩 5A",
          "CAM-TL00": "华为 荣耀畅玩5A",
          "CHE-TL00": "华为 荣耀 畅玩 4X",
          "Che1-CL20": "华为 荣耀畅玩 4X",
          "Che2-TL00M": "华为 荣耀 畅玩 4X",
          "CHM-CL00": "华为 荣耀 4C 电信版",
          "CHM-UL00": "华为 荣耀 4C",
          "CLT-TL01": "华为 P20 Pro",
          "COL-AL10": "华为 荣耀 10",
          "Coolpad 8297-T01": "酷派 大神 F1",
          "Coolpad 8297W": "酷派 大神 F1",
          "Coolpad 8675": "酷派 大神 F2 移动版",
          "Coolpad 8675-A": "酷派 大神 F2",
          "Coolpad 8702D": "酷派 8720D",
          "Coolpad 8705": "酷派 8705",
          "Coolpad Y75": "酷派 锋尚",
          "Coolpad Y803-9": "酷派 锋尚3",
          "Coolpad Y80D": "酷派 锋尚",
          "COR-AL00": "华为 荣耀Play",
          "CUN-TL00": "华为 荣耀畅玩 5",
          "d-02H": "华为 docomo dtab Compact",
          "DE106": "坚果 R1",
          "DIG-AL00": "华为 畅享 6S",
          "DLI-AL10": "华为 荣耀畅玩 6A",
          "DOOV L9": "朵唯 L9",
          "DOOV S2": "朵唯 S2",
          "DRA-AL00": "华为 畅享 8e ",
          "DUA-AL00": "华为 荣耀畅玩 7",
          "DUK-AL20": "华为 荣耀 V9",
          "E6": "金立 E6",
          "E6533": "索尼 Xperia Z3",
          "E6653": "索尼 Xperia Z",
          "E6883": "索尼 Xperia Z5",
          "E6mini": "金立 E6 mini",
          "E7": "金立 E7",
          "EDI-AL10": "华为 荣耀 Note8",
          "EML-AL00": "华为 P20",
          "EVA-AL00": "华为 P9",
          "EVR-AL00": "华为 Mate 20 X",
          "F-01H": "富士通 ARROWS ",
          "F-01J": "富士通 ARROWS",
          "F-02G": "富士通 F-02G",
          "F-02H": "富士通 ARROWS NX ",
          "F-04G": "富士通 ARROWS NX",
          "F-04H": "ARROWS Tab",
          "F100": "金立 F100",
          "F100S": "金立 F100",
          "F103": "金立 F103",
          "F106": "金立 F106",
          "F301": "金立 F301",
          "F8332": "索尼 Xperia XZ",
          "FIG-AL00": "华为 畅享 7S",
          "FLA-AL10": "华为 畅享 8 Plus",
          "FRD-AL00": "华为 荣耀 8",
          "FRD-AL10": "华为 荣耀 8",
          "FS8010": "夏普 AQUOS S2",
          "G620S-UL00": "华为 荣耀 畅玩4",
          "G8232": "索尼 Xperia XZs",
          "GEM-703L": "华为 荣耀 X2",
          "GIONEE F205L": "金立 F205",
          "GIONEE F6L": "金立 F6",
          "GIONEE GN5007": "金立 大金刚 2",
          "GIONEE M7": "金立 M7",
          "GIONEE S10": "金立 S10",
          "GIONEE S11": "金立 S11",
          "GIONEE S11S": "金立 S11s",
          "GN151": "金立 GN151",
          "GN5001S": "金立 金钢",
          "GN5003": "金立 大金钢",
          "GN5005": "金立 金钢 2",
          "GN8002S": "金立 M6 Plus",
          "GN8003": "金立 M6",
          "GN9000": "金立 S5.5",
          "GN9000L": "金立 S5.5L",
          "GN9005": "金立 S5.1",
          "GN9006": "金立 S7",
          "GN9012": "金立 S6 Pro",
          "GRA-A0": "酷派 酷玩 6C",
          "GT-810": "掠夺者8 A5002",
          "GT-I9060I": "三星 Galaxy Grand Neo Plus",
          "GT-I9152": "三星 GT-I9152",
          "GT-I9158P": "三星 Galaxy Mega",
          "GT-I9208": "三星 GT-I9208",
          "GT-I9300": "三星 Galaxy S3",
          "GT-I9500": "三星 GalaxyS4",
          "GT-I9507V": "三星 Galaxy S4",
          "GT-I9508": "三星 Galaxy S4",
          "GT-N7100": "三星 Galaxy Note 2",
          "GT-N7108": "三星 Galaxy Note 2",
          "H30-T00": "华为 荣耀3C",
          "H30-T10": "华为 荣耀3C",
          "H30-U10": "华为 荣耀3C",
          "H60-L01": "华为 荣耀 6",
          "H60-L03": "华为 荣耀 6",
          "H8296": "索尼 Xperia XZ2",
          "Hisense A2": "海信 A2",
          "Hisense E76": "海信 E76",
          "HLA NOTE1-L": "红辣椒 Note",
          "HM 1S": "红米 1S",
          "HM 2A": "红米 2A",
          "HM NOTE 1LTE": "红米 Note",
          "HM NOTE 1S": "红米 Note",
          "HM NOTE 1TD": "红米 Note",
          "HTC 2Q4D200": "HTC U11+",
          "HTC 2Q4R400": "HTC U11 EYEs",
          "HTC 2Q55300": "HTC U12+",
          "HTC 802w": "HTC One M7",
          "HTC 8088": "HTC One max",
          "HTC 9088": "HTC Butterfly S",
          "HTC A9w": "HTC One A9",
          "HTC D10w": "HTC Desire 10 Pro",
          "HTC D816w": "HTC Desire 816",
          "HTC D820u": "HTC D820u",
          "HTC D830u": "HTC Desire 830",
          "HTC Desire EYE": "HTC Desire Eye",
          "HTC M10u": "HTC 10",
          "HTC M8t": "HTC One E8",
          "HTC One A9": "HTC One A9",
          "HTC One M9PLUS": "HTC M9 台版",
          "HTC One X9 dual sim": "HTC One X9",
          "HTC U Ultra": "HTC U Ultra 港版",
          "HTC U-1w": "HTC U Ultra",
          "HTC_M10h": "HTC 10",
          "HTC_M9u": "HTC One M9",
          "HUAWEI CAZ-AL10": "华为 nova",
          "HUAWEI CAZ-TL20": "华为 nova",
          "HUAWEI G606-T00": "华为 G606-T00",
          "HUAWEI G610-U00": "华为 G610",
          "HUAWEI G7-TL00": "华为 G7",
          "HUAWEI G700-T00": "华为 G700-T00",
          "HUAWEI G700-U00": "华为 G700-U00",
          "HUAWEI G750-T01": "华为 荣耀3X",
          "HUAWEI GRA-CL10": "华为 P8 高配版",
          "HUAWEI GRA-TL00": "华为 P8",
          "HUAWEI GRA-UL00": "华为 P8",
          "HUAWEI M2-801W": "华为 MediaPad",
          "HUAWEI M2-A01W": "华为 MediaPad",
          "HUAWEI MLA-AL00": "华为 麦芒 5",
          "HUAWEI MLA-TL10": "华为 G9 Plus",
          "HUAWEI MLA-UL00": "华为 G9 Plus",
          "HUAWEI MT2-L01": "华为 Mate 2",
          "HUAWEI MT7-TL00": "华为 Mate 7",
          "HUAWEI MT7-TL10": "华为 Mate 7",
          "HUAWEI NXT-AL10": "华为 Mate 8",
          "HUAWEI NXT-DL00": "华为 Mate 8",
          "HUAWEI P6 S-U06": "华为 P6 S",
          "HUAWEI P6-T00": "华为 P6",
          "HUAWEI P7-L00": "华为 P7",
          "HUAWEI P7-L05": "华为 P7",
          "HUAWEI P7-L07": "华为 P7",
          "HUAWEI P8max": "华为 P8max",
          "HUAWEI RIO-AL00": "华为 麦芒 4",
          "HUAWEI RIO-CL00": "华为 麦芒 4",
          "HUAWEI RIO-TL00": "华为 G7 Plus",
          "HUAWEI TAG-AL00": "华为 畅享 5S",
          "HUAWEI TAG-TL00": "华为 畅享 5S",
          "HUAWEI TIT-AL00": "华为 畅享 5",
          "HUAWEI VNS-AL00": "华为 G9",
          "HUAWEI VNS-L21": "华为 P9 Lite",
          "HUAWEI VNS-TL00": "华为 G9",
          "HWI-AL00": "华为 nova 2S",
          "HWT31": "华为 au Qua tab",
          "IM-A870L": "泛泰 VEGA",
          "INE-AL00": "华为 nova 3i",
          "JMM-AL00": "华为 荣耀 V9 Play",
          "JSN-AL00a": "华为 荣耀 8X",
          "K011": "华硕 Memo Pad",
          "KIW-AL10": "华为 荣耀畅玩 5X",
          "KIW-TL00H": "华为 荣耀畅玩 5X",
          "KNT-AL10": "华为 荣耀 V8",
          "KNT-TL10": "华为 荣耀 V8",
          "KOB-W09": "华为 荣耀畅玩",
          "KYT31": "KYOCERA au Qua tab",
          "L36h": "索尼 Z",
          "L39h": "索尼 Xperia Z1",
          "L50w": "索尼 Xperia Z2",
          "LA7-L": "小辣椒 7",
          "LDN-AL00": "华为 畅享 8",
          "Le X507": "乐视 乐1s",
          "Le X620": "乐视 乐2",
          "Le X625": "乐视 乐2 Pro",
          "Le X820": "乐视 乐Max 2",
          "Lenovo A788t": "联想 A788t",
          "Lenovo A808t": "联想 黄金斗士A8",
          "Lenovo A808t-i": "联想 黄金斗士A8",
          "Lenovo A850": "联想 A850",
          "Lenovo K30-T": "联想 乐檬 K3",
          "Lenovo K900": "联想 K900",
          "Lenovo K920": "联想 K920",
          "Lenovo L78011": "联想 Z5",
          "Lenovo P2c72": "联想 VIBE P2",
          "Lenovo P70-t": "联想 P70t",
          "Lenovo PB2-690N": "联想 Phab2 Pro",
          "Lenovo S60-t": "联想 S60t",
          "Lenovo S850t": "联想 S850t",
          "Lenovo S868t": "联想 S868t",
          "Lenovo S90-t": "联想 笋尖S90",
          "Lenovo X2-TO": "联想 VIBE X2",
          "Letv X500": "乐视 乐1s",
          "LEX720": "乐视 乐Pro3",
          "LG-D486": "LG D486",
          "LG-D855": "LG G3",
          "LG-E985T": "LG E985T",
          "LG-H818": "LG G4",
          "LG-H860": "LG G5",
          "LG-H968": "LG V10",
          "LG-M250": "LG K10 2017",
          "LGMS210": "LG Aristo MS210",
          "LGT31": "LGT 31",
          "LGV32": "LG G4",
          "LLD-AL00": "华为 荣耀 9 青春版",
          "LLD-AL20": "华为 荣耀 9i",
          "LND-AL30": "华为 荣耀畅玩 7C",
          "LON-AL00": "华为 Mate 9 Pro",
          "LYA-AL00": "华为 Mate 20 Pro",
          "M040": "魅族 MX2",
          "M1 E": "魅族 魅蓝 E",
          "m1 metal": "魅族 魅蓝 Metal",
          "m1 note": "魅族 魅蓝 Note",
          "m1": "魅族 魅蓝",
          "M15": "魅族 M15",
          "M1813": "魅族 V8 高配版",
          "M1816": "魅族 V8 标准版",
          "M1852": "魅族 X8",
          "M2 E": "魅族 魅蓝 E2",
          "m2 note": "魅族 魅蓝 Note 2",
          "m2": "魅族 魅蓝 2",
          "M3 Max": "魅族 魅蓝 Max",
          "m3 note": "魅族 魅蓝 Note 3",
          "M351": "魅族 MX3",
          "M3s": "魅族 魅蓝 3S",
          "M3X": "魅族 魅蓝 X",
          "M463C": "魅族 魅蓝 Note 电信版",
          "M5 Note": "魅族 魅蓝 Note 5",
          "M5": "魅族 魅蓝 5",
          "M5s": "魅族 魅蓝 5S",
          "M6 Note": "魅族 魅蓝 Note 6",
          "M6": "魅族 魅蓝 6",
          "M623C": "中国移动 A1",
          "M651CY": "中国移动 A3",
          "M760": "中国移动 A4s",
          "Meitu M4": "美图 M4",
          "Meizu 6T": "魅族 魅蓝 6T",
          "MEIZU E3": "魅族 魅蓝 E3",
          "Meizu S6": "魅族 魅蓝 S6",
          "MHA-AL00": "华为 Mate 9",
          "MHA-L29": "华为 Mate 9 国际版",
          "MI 2": "小米 2",
          "MI 2A": "小米 2A",
          "MI 3": "小米 3 移动版",
          "MI 3C": "小米 3 电信版",
          "MI 3W": "小米 3 联通版",
          "MI 4LTE": "小米 4 ",
          "MI 4S": "小米 4S",
          "MI 4W": "小米 4 联通版",
          "MI 5": "小米 5",
          "MI 5C": "小米 5C",
          "MI 5s Plus": "小米 5S Plus",
          "MI 5s": "小米 5S",
          "MI 5X": "小米 5X",
          "MI 6": "小米 6",
          "MI 6X": "小米 6X",
          "MI 8 Explorer Edition": "小米 8 透明探索版",
          "MI 8 Lite": "小米 8 青春版",
          "MI 8 SE": "小米 8 SE",
          "MI 8 UD": "小米 8",
          "MI 8": "小米 8",
          "Mi A1": "小米 A1",
          "MI MAX 2": "小米 MAX 2",
          "MI MAX 3": "小米 Max 3",
          "MI MAX": "小米 Max",
          "Mi Note 2": "小米 Note 2",
          "Mi Note 3": "小米 Note 3",
          "MI NOTE LTE": "小米 Note",
          "MI NOTE Pro": "小米 Note 顶配版",
          "MI PAD 2": "小米 平板2",
          "MI PAD 3": "小米 平板3",
          "MI PAD 4 PLUS": "小米 平板4 Plus",
          "MI PAD 4": "小米 平板4",
          "MI PAD": "小米 平板",
          "Mi-4c": "小米 4C 标准版",
          "MI-ONE Plus": "小米 1",
          "MIX 2": "小米 MIX 2",
          "MIX 2S": "小米 MIX 2S",
          "MIX 3": "小米 MIX 3",
          "MIX": "小米 MIX",
          "Moto E (4)": "Moto E",
          "Moto G (5) Plus": "Moto G5 Plus",
          "Moto G (5)": "Moto G5",
          "Moto X Pro": "Moto X Pro",
          "MP1503": "美图 M6",
          "MX4 Pro": "魅族 MX4 Pro",
          "MX4": "魅族 MX4",
          "MX5": "魅族 MX5",
          "MX6": "魅族 MX6",
          "MYA-AL10": "华为 荣耀畅玩 6",
          "MYA-L22": "华为 Y5",
          "N1": "诺基亚 N1",
          "N1T": "OPPO N1T",
          "N5207": "OPPO N3",
          "NCE-AL00": "华为 畅享 6",
          "NCE-AL10": "华为 畅享 6",
          "NCE-TL10": "华为 畅享 6",
          "NEM-AL10": "华为 荣耀 畅玩5C",
          "NEM-TL00": "华为 荣耀 畅玩5C",
          "NEM-TL00H": "华为 荣耀 畅玩5C",
          "NEO-AL00": "华为 Mate RS",
          "Nexus 4": "Google Nexus 4",
          "Nexus 5": "Google Nexus 5",
          "Nexus 5X": "Google Nexus 5X",
          "Nexus 6": "Google Nexus 6",
          "Nexus 6P": "Google Nexus 6P",
          "Nexus 9": "Google Nexus 9",
          "Nokia 7 plus": "诺基亚 7 Plus",
          "Nokia 8 Sirocco": "诺基亚 8 Sirocco",
          "Nokia X5": "诺基亚 X5",
          "Nokia X6": "诺基亚 X6",
          "NTS-AL00": "华为 荣耀 Magic",
          "NX403A": "努比亚 Z5S mini",
          "NX508J": "努比亚 Z9",
          "NX513J": "努比亚 My",
          "NX529J": "努比亚 Z11 mini",
          "NX531J": "努比亚 Z11",
          "NX563J": "努比亚 Z17",
          "NX569J": "努比亚 Z17 mini ",
          "NX573J": "努比亚 M2",
          "NX575J": "努比亚 N2",
          "NX595J": "努比亚 Z17S",
          "NX609J": "努比亚 红魔手机",
          "NXT-AL10": "华为 Mate 8",
          "OC105": "锤子 坚果 3",
          "OD103": "锤子 坚果 Pro",
          "OE106": "锤子 坚果 Pro 2S",
          "ONE A2001": "一加 2",
          "ONEPLUS A3000": "一加 3",
          "ONEPLUS A3010": "一加 3T",
          "ONEPLUS A5000": "一加 5",
          "ONEPLUS A5010": "一加 5T",
          "ONEPLUS A6000": "一加 6",
          "OPPO A30": "OPPO A30",
          "OPPO A33": "OPPO A33",
          "OPPO A33m": "OPPO A33",
          "OPPO A37m": "OPPO A37",
          "OPPO A53": "OPPO A53",
          "OPPO A53m": "OPPO A53",
          "OPPO A57": "OPPO A57",
          "OPPO A59m": "OPPO A59",
          "OPPO A59s": "OPPO A59s",
          "OPPO A73": "OPPO A73",
          "OPPO A77": "OPPO A77",
          "OPPO A79": "OPPO A79",
          "OPPO A83": "OPPO A83",
          "OPPO R11 Plus": "OPPO R11 Plus",
          "OPPO R11 Plusk": "OPPO R11 Plus",
          "OPPO R11": "OPPO R11",
          "OPPO R11s Plus": "OPPO R11s Plus",
          "OPPO R11s": "OPPO R11s",
          "OPPO R11st": "OPPO R11s",
          "OPPO R11t": "OPPO R11",
          "OPPO R7": "OPPO R7",
          "OPPO R7s": "OPPO R7s ",
          "OPPO R7sm": "OPPO R7s 全网通",
          "OPPO R9 Plustm A": "OPPO R9 Plus",
          "OPPO R9m": "OPPO R9",
          "OPPO R9s Plus": "OPPO R9s Plus",
          "OPPO R9s": "OPPO R9s",
          "OPPO R9sk": "OPPO R9s",
          "OPPO R9tm": "OPPO R9",
          "OS105": "锤子 坚果 Pro 2",
          "PAAM00": "OPPO R15",
          "PADM00": "OPPO A3",
          "PAFM00": "OPPO Find X",
          "PAR-AL00": "华为 nova 3",
          "PBAM00": "OPPO A5",
          "PBEM00": "OPPO R17",
          "PE-CL00": "华为 荣耀 6 Plus",
          "PE-TL10": "华为 荣耀 6 Plus",
          "PH-1": "Essential Phone",
          "PIC-AL00": "华为 nova 2",
          "Pixel 2 XL": "Google Pixel 2 XL",
          "Pixel XL": "Google Pixel XL",
          "Pixel": "Google Pixel",
          "PLAYER": "小辣椒 Player",
          "PLK-CL00": "华为 荣耀 7",
          "PLK-TL01H": "华为 荣耀 7",
          "PLK-UL00": "华为 荣耀 7",
          "POCOPHONE F1": "POCOPHONE F1",
          "PP5600": "PPTV M1",
          "PRA-AL00": "华为 荣耀 8 青春版",
          "PRA-AL00X": "华为 荣耀 8 青春版",
          "PRO 5": "魅族 Pro 5",
          "PRO 6 Plus": "魅族 Pro 6 Plus",
          "PRO 6": "魅族 Pro 6",
          "PRO 6s": "魅族 Pro 6s",
          "PRO 7 Plus": "魅族 Pro 7 Plus",
          "PRO 7-S": "魅族 Pro 7",
          "R2017": "OPPO R2017",
          "R6007": "OPPO R6007",
          "R7007": "OPPO R3",
          "R7c": "OPPO R7 电信版",
          "R7Plus": "OPPO R7 Plus 移动版",
          "R7Plusm": "OPPO R7 Plus 全网通",
          "R8107": "OPPO R8107",
          "R819T": "OPPO R819T",
          "R8207": "OPPO R1C",
          "R821T": "OPPO R821T",
          "R831S": "OPPO R831s",
          "R831T": "OPPO R831T",
          "ramos MOS 1": "蓝魔 MOS1",
          "ramos MOS1max": "蓝魔 MOS1 MAX",
          "Redmi 3": "红米 3",
          "Redmi 3S": "红米 3S",
          "Redmi 3X": "红米 3X",
          "Redmi 4": "红米 4",
          "Redmi 4A": "红米 4A",
          "Redmi 4X": "红米 4X",
          "Redmi 5 Plus": "红米 5 Plus",
          "Redmi 5": "红米 5",
          "Redmi 5A": "红米 5A",
          "Redmi 6 Pro": "红米 6 Pro",
          "Redmi 6A": "红米 6A",
          "Redmi Note 2": "红米 Note 2",
          "Redmi Note 3": "红米 Note 3",
          "Redmi Note 4": "红米 Note 4",
          "Redmi Note 4X": "红米 Note 4X",
          "Redmi Note 5": "红米 Note 5",
          "Redmi Note 5A": "红米 Note 5A",
          "Redmi Pro": "红米 Pro",
          "Redmi S2": "红米 S2",
          "RNE-AL00": "华为 麦芒 6",
          "RVL-AL09": "华为 荣耀 Note10",
          "S39h": "索尼 Xperia C",
          "S9": "金立 S9",
          "SAMSUNG-SM-G930A": "三星 Galaxy S7 美版",
          "SC-03J": "三星 Galaxy S8",
          "SC-04E": "三星 Galaxy S4",
          "SC-04F": "三星 Galaxy S5",
          "SC-04G": "三星 Galaxy S6 Edg",
          "SC-04J": "三星 Galaxy Feel",
          "SC-05G": "三星 Galaxy S6",
          "SCH-I939I": "三星 Galaxy S3 Neo+",
          "SCL-AL00": "华为 荣耀 4A",
          "SCV31": "三星 Galaxy S6 Edge",
          "SCV35": "三星 Galaxy S8+",
          "SCV36": "三星 Galaxy S8",
          "SD4930UR": "Amzon Fire Phone",
          "SGH-N075T": "三星 Galaxy J",
          "SKR-A0": "黑鲨 游戏手机",
          "SLA-AL00": "华为 畅享 7",
          "SM-A3000": "三星 Galaxy A3",
          "SM-A5000": "三星 Galaxy A5",
          "SM-A5100": "三星 Galaxy A5",
          "SM-A520S": "三星 Galaxy A5",
          "SM-A7000": "三星 Galaxy A7",
          "SM-C5010": "三星 Galaxy C5 Pro",
          "SM-C7000": "三星 Galaxy C7",
          "SM-C7010": "三星 Galaxy C7 Pro",
          "SM-C7100": "三星 Galaxy C8",
          "SM-C9000": "三星 Galaxy C9 Pro",
          "SM-E7000": "三星 Galaxy E7",
          "SM-G5309W": "三星 Galaxy GRAND",
          "SM-G530H": "三星 Galaxy Grand Prime ",
          "SM-G532F": "三星 Grand Prime Plus",
          "SM-G5500": "三星 Galaxy On5",
          "SM-G6000": "三星 Galaxy On7",
          "SM-G7108V": "三星 Galaxy Grand 2",
          "SM-G8508S": "三星 Galaxy Alpha",
          "SM-G8750": "三星 Galaxy S ",
          "SM-G9006W": "三星 Galaxy S5",
          "SM-G9008V": "三星 Galaxy S5",
          "SM-G900V": "三星 Galaxy S5",
          "SM-G910S": "三星 Galaxy Round",
          "SM-G9200": "三星 Galaxy S6",
          "SM-G920F": "三星 Galaxy S6",
          "SM-G920V": "三星 Galaxy S6",
          "SM-G9250": "三星 Galaxy S6 Edge",
          "SM-G925V": "三星 Galaxy S6 Edge",
          "SM-G9280": "三星 Galaxy S6 Edge+",
          "SM-G9300": "三星 Galaxy S7",
          "SM-G9308": "三星 Galaxy S7",
          "SM-G930F": "三星 Galaxy S7",
          "SM-G9350": "三星 Galaxy S7 Edge",
          "SM-G935F": "三星 Galaxy S7 Edge",
          "SM-G935V": "三星 Galaxy S7 Edge",
          "SM-G9500": "三星 Galaxy S8",
          "SM-G950F": "三星 Galaxy S8",
          "SM-G9550": "三星 Galaxy S8+",
          "SM-G955N": "三星 Galaxy S8+",
          "SM-G9600": "三星 Galaxy S9",
          "SM-G960N": "三星 Galaxy S9 ",
          "SM-G960U": "三星 Galaxy S9",
          "SM-G965N": "三星 Galaxy S9+",
          "SM-G965U": "三星 Galaxy S9+",
          "SM-J5008": "三星 Galaxy J5",
          "SM-J7008": "三星 Galaxy J7",
          "SM-J701F": "三星 Galaxy J7",
          "SM-J7109": "三星 Galaxy J7",
          "SM-J730GM": "三星 Galaxy J7 Pro",
          "SM-N9002": "三星 Galaxy Note 3",
          "SM-N9008V": "三星 Galaxy Note 3",
          "SM-N900A": "三星 Galaxy Note 3",
          "SM-N9100": "三星 Galaxy Note 4",
          "SM-N910U": "三星 Galaxy Note 4",
          "SM-N9200": "三星 Galaxy Note 5",
          "SM-N9208": "三星 Galaxy Note 5",
          "SM-N920K": "三星 Galaxy Note 5",
          "SM-N9500": "三星 Galaxy Note 8",
          "SM-N950N": "三星 Galaxy Note 8",
          "SM-N950U1": "三星 Galaxy Note 8",
          "SM-N9600": "三星 Galaxy Note 9",
          "SM-P601": "三星 Galaxy Note 10.1",
          "SM-T110": "三星 Galaxy Tab3",
          "SM-T113": "三星 Tab E Lite",
          "SM-T310": "三星 GALAXY Tab3",
          "SM-T560": "三星 Galaxy Tab E",
          "SM-T580": "三星 Galaxy Tab A",
          "SM-T817V": "三星 Galaxy Tab S2",
          "SM701": "锤子 T1",
          "SM901": "锤子 M1",
          "SM919": "锤子 M1L",
          "SNE-AL00": "华为 麦芒 7",
          "SO-03G": "索尼 Xperia Z4",
          "SO-04H": "索尼 Xperia X Performance",
          "SO-04J": "索尼 Xperia XZ Premium",
          "SOV31": "索尼 Xperia Z4",
          "SOV35": "索尼 Xperia XZs",
          "STF-AL00": "华为 荣耀 9",
          "STF-AL10": "华为 荣耀 9",
          "TA-1000": "诺基亚 6",
          "TA-1041": "诺基亚 7",
          "TA-1052": "诺基亚 8",
          "TCL 520": "TCL 520",
          "TCL 750": "TCL 750",
          "TRT-AL00": "华为 畅享 7 Plus",
          "U10": "魅族 魅蓝 U10",
          "V1732A": "vivo Y81s",
          "V1809A": "vivo X23",
          "V1813A": "vivo Y97",
          "V182": "金立 V182",
          "V183": "金立 V183",
          "V185": "金立 V185",
          "V188S": "金立 V188S",
          "V8": "天语 V8",
          "VCR-A0": "酷派 酷玩 6",
          "VIE-AL10": "华为 P9 Plus",
          "Vivo 5R": "BLU vivo 5R",
          "vivo NEX A": "vivo NEX 标准版",
          "vivo NEX S": "vivo NEX 旗舰版",
          "vivo V3": "vivo V3",
          "vivo V3M A": "vivo V3M",
          "vivo V3Max A": "vivo V3Max",
          "vivo V3Max": "vivo V3Max",
          "vivo X20A": "vivo X20",
          "vivo X20Plus A": "vivo X20 Plus",
          "vivo X20Plus UD": "vivo X20 PlusUD",
          "vivo X20Plus": "vivo X20 Plus",
          "vivo X21A": "vivo X21",
          "vivo X21i A": "vivo X21i",
          "vivo X21UD A": "vivo X21UD",
          "vivo X3L": "vivo X3L",
          "vivo X3t": "vivo X3T",
          "vivo X5L": "vivo X5L",
          "vivo X5M": "vivo X5M",
          "vivo X5Max V": "vivo X5 Max V",
          "vivo X5Max+": "vivo X5Max+",
          "vivo X5Pro D": "vivo X5Pro",
          "vivo X5Pro V": "vivo X5Pro V",
          "vivo X5S L": "vivo X5 SL",
          "vivo X6A": "vivo X6A",
          "vivo X6D": "vivo X6D",
          "vivo X6Plus A": "vivo X6 Plus A",
          "vivo X6Plus D": "vivo X6 Plus",
          "vivo X6Plus L": "vivo X6 Plus",
          "vivo X6S A": "vivo X6S",
          "vivo X6SPlus D": "vivo X6S Plus",
          "vivo X7": "vivo X7",
          "vivo X7Plus": "vivo X7 Plus",
          "vivo X9": "vivo X9",
          "vivo X9i": "vivo X9",
          "vivo X9Plus": "vivo X9 Plus",
          "vivo X9s Plus": "vivo X9s Plus",
          "vivo X9s": "vivo X9s",
          "vivo Xplay3S": "vivo Xplay 3S",
          "vivo Xplay5A": "vivo Xplay5",
          "vivo Xplay6": "vivo Xplay6",
          "vivo Y11i T": "vivo Y11iT",
          "vivo Y13L": "vivo Y13L",
          "vivo Y23L": "vivo Y23L",
          "vivo Y27": "vivo Y27",
          "vivo Y29L": "vivo Y29L",
          "vivo Y31A": "vivo Y31A",
          "vivo Y33": "vivo Y33",
          "vivo Y35": "vivo Y35L",
          "vivo Y35A": "vivo Y35A",
          "vivo Y35L": "vivo Y35L",
          "vivo Y37": "vivo Y37",
          "vivo Y51A": "vivo Y51A",
          "vivo Y53": "vivo Y53",
          "vivo Y55": "vivo Y55A",
          "vivo Y66": "vivo Y66",
          "vivo Y67": "vivo Y67",
          "vivo Y67A": "vivo Y67",
          "vivo Y69A": "vivo Y69",
          "vivo Y71A": "vivo Y71",
          "vivo Y75": "vivo Y75",
          "vivo Y75s": "vivo Y75s",
          "vivo Y79A": "vivo Y79",
          "vivo Y83A": "vivo Y83（HIH-PHO-3360）",
          "vivo Y85A": "vivo Y85",
          "vivo Y913": "vivo Y13L",
          "vivo Z1": "vivo Z1（HIH-PHO-3368）",
          "vivo Z1i": "vivo Z1i（HIH-PHO-3506）",
          "vivo": "vivo Y75",
          "VKY-AL00": "华为 P10 Plus",
          "VTR-AL00": "华为 P10",
          "W800": "金立 天鉴 w800",
          "WAS-AL00": "华为 nova 青春版",
          "X9007": "OPPO Find 7 轻装版",
          "X9077": "OPPO Find 7",
          "XT1052": "Moto X（一代）",
          "XT1060": "Moto X（一代）",
          "XT1079": "Moto G 二代",
          "XT1085": "Moto X 二代",
          "XT1096": "Moto X 二代",
          "XT1570": "Moto X Style",
          "XT1635-03": "Moto Z Play",
          "XT1650": "Moto Z",
          "XT1650-05": "Moto Z",
          "XT1662": "Moto M（XT1662）",
          "XT1710-08": "Moto Z2 Play",
          "XT1789-05": "Moto Z 2018",
          "XT1799-2": "Moto 青柚",
          "XT907": "Moto XT907",
          "Y13L": "vivo Y13L",
          "Y23L": "vivo Y23L",
          "Y35A": "vivo Y35A",
          "YQ601": "锤子 坚果手机",
          "Z999": "中兴 Axon M",
          "ZTE A0722": "中兴 Blade A4",
          "ZTE BA610C": "中兴 远航4",
          "ZTE BV0710": "中兴 V7 MAX",
          "ZTE BV0720": "中兴 Blade A2",
          "ZTE BV0730": "中兴 Blade A2 Plus",
          "ZTE C2017": "中兴 天机7Max",
          "ZTE C880U": "中兴 Blade A1",
          "ZTE U930HD": "中兴 U930 HD",
          "ZTE V0900": "中兴 Blade V9",
          "ZTE V975": "中兴 V975",
          "ZUK Z1": "ZUK Z1（Z1221）",
          "ZUK Z2121": "ZUK Z2 Pro（Z2121）",
          "ZUK Z2131": "ZUK Z2",
          "ZUK Z2151": "ZUK Edge"
          }
